# Keep compatibility with 2.30 and older

check_deps() {
	if compatibility_level_is_at_least '2.31'; then
		warning_deprecated_function 'check_deps' 'requirements_check'
	fi

	requirements_check
}

requirements_list_explicit_legacy() {
	local requirements_list_legacy
	requirements_list_legacy=${SCRIPT_DEPS:-}
	if \
		compatibility_level_is_at_least '2.31' && \
		[ -n "$requirements_list_legacy" ]
	then
		warning_deprecated_variable 'SCRIPT_DEPS' 'REQUIREMENTS_LIST'
		printf '%s\n' $requirements_list_legacy
	fi
}

